/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader;

import yet.another.hackernews.reader.data.API;
import android.os.Bundle;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTransaction;

import com.actionbarsherlock.app.ActionBar;
import com.actionbarsherlock.app.ActionBar.Tab;

public class HackernewsActivity extends MenuActivity {

	private int attachedFragment;
	private int lastFragment;

	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.fragment_hackernews);

		final ActionBar bar = getSupportActionBar();

		{
			// Latest
			final ActionBar.Tab homepage = bar.newTab();
			homepage.setText(getString(R.string.tab_latest));
			final HackernewsFragment homepageFragment = new HomepageFragment();
			homepage.setTabListener(new MyTabsListener(homepageFragment));
			bar.addTab(homepage);

			// Newest
			final ActionBar.Tab newest = bar.newTab();
			newest.setText(getString(R.string.tab_newest));
			final HackernewsFragment newestFragment = new NewestFragment();
			newest.setTabListener(new MyTabsListener(newestFragment));
			bar.addTab(newest);

			// Best
			final ActionBar.Tab best = bar.newTab();
			best.setText(getString(R.string.tab_best));
			final HackernewsFragment bestFragment = new BestFragment();
			best.setTabListener(new MyTabsListener(bestFragment));
			bar.addTab(best);

			// ask
			final ActionBar.Tab ask = bar.newTab();
			ask.setText(getString(R.string.tab_ask));
			final HackernewsFragment askFragment = new AskFragment();
			ask.setTabListener(new MyTabsListener(askFragment));
			bar.addTab(ask);
		}

		lastFragment = 0;

		if (savedInstanceState != null) {
			attachedFragment = savedInstanceState.getInt("tab", 0);
			bar.setSelectedNavigationItem(attachedFragment);
		} else {
			attachedFragment = 0;
		}
	}

	@Override
	protected void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);

		outState.putInt("tab", getSupportActionBar()
				.getSelectedNavigationIndex());
	}

	@Override
	public void refresh() {
		super.refresh();

		FragmentManager fm = getSupportFragmentManager();
		HackernewsFragment fragment = (HackernewsFragment) fm
				.findFragmentById(R.id.fragment_hackernews);
		
		if(!fragment.isVisible()) {
			return;
		}

		if (fragment != null) {
			switch (attachedFragment) {
			case 0:
				fragment.updateList(API.getHomepage(), true);
				break;
			case 1:
				fragment.updateList(API.getNewest(), true);
				break;
			case 2:
				fragment.updateList(API.getBest(), true);
			case 3:
				fragment.updateList(API.getAsk(), true);
				break;
			default:
				// Nothing
			}

		}
	}

	protected void handleError() {
		getSupportActionBar().setSelectedNavigationItem(lastFragment);
	}

	protected class MyTabsListener implements ActionBar.TabListener {

		private final HackernewsFragment fragment;

		public MyTabsListener(HackernewsFragment fragment) {
			this.fragment = fragment;
		}

		public void onTabReselected(Tab tab, FragmentTransaction ft) {
		}

		public void onTabSelected(Tab tab, FragmentTransaction ft) {
			if (attachedFragment == tab.getPosition()) {
				return;
			}

			attachedFragment = tab.getPosition();

			if (fragment != null) {
				if (fragment.isDetached()) {
					ft.attach(fragment);
				} else {
					ft.add(fragment, null);
				}
			}
		}

		public void onTabUnselected(Tab tab, FragmentTransaction ft) {
			lastFragment = tab.getPosition();

			if (fragment != null) {
				ft.detach(fragment);
			}
		}

	}
}