/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader.data;

import org.json.JSONException;
import org.json.JSONObject;

public class News {

	private static final String TITLE_KEY = "title";
	private static final String URL_KEY = "url";
	private static final String POINTS_KEY = "score";
	private static final String POSTED_AGO_KEY = "time";
	private static final String POSTED_BY_KEY = "user";
	private static final String COMMENTS_KEY = "comments";
	private static final String ITEM_ID_KEY = "item_id";

	String URL;
	String title;
	String points;
	String postedAgo;
	String postedBy;
	String comments;
	int itemID;

	public News() {

	}

	/**
	 * Constructs a News element from a JSON object.
	 * 
	 * @param object
	 */
	public News(JSONObject object) {
		try {
			this.setTitle(object.getString(TITLE_KEY));
			this.setURL(object.getString(URL_KEY));
			this.setPoints(object.getString(POINTS_KEY));
			this.setPostedAgo(object.getString(POSTED_AGO_KEY));
			this.setPostedBy(object.getString(POSTED_BY_KEY));
			this.setComments(object.getString(COMMENTS_KEY));
			this.setItemID(object.getInt(ITEM_ID_KEY));
		} catch (JSONException e) {
		}
	}

	public String getComments() {
		return comments;
	}

	public void setComments(String comments) {
		this.comments = comments;
	}

	public String getPoints() {
		return points;
	}

	public void setPoints(String points) {
		this.points = points;
	}

	public String getPostedAgo() {
		return postedAgo;
	}

	public void setPostedAgo(String postedAgo) {
		this.postedAgo = postedAgo;
	}

	public String getPostedBy() {
		return postedBy;
	}

	public void setPostedBy(String postedBy) {
		this.postedBy = postedBy;
	}

	public String getURL() {
		return URL;
	}

	public void setURL(String URL) {
		if (URL.startsWith("item?id=")) {
			URL = "http://news.ycombinator.com/" + URL;
		}

		this.URL = URL;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		if (title.equals("NextId")) {
			title = "More";
		}

		this.title = title;
	}

	public int getItemID() {
		return itemID;
	}

	public void setItemID(int itemID) {
		this.itemID = itemID;
	}

	@Override
	public String toString() {
		JSONObject object = new JSONObject();

		try {
			object.put(TITLE_KEY, getTitle());
			object.put(URL_KEY, getURL());
			object.put(POINTS_KEY, getPoints());
			object.put(POSTED_AGO_KEY, getPostedAgo());
			object.put(POSTED_BY_KEY, getPostedBy());
			object.put(COMMENTS_KEY, getComments());
			object.put(ITEM_ID_KEY, getItemID());
		} catch (JSONException e) {
		}

		return object.toString();

	}

}
