/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader.database;

import yet.another.hackernews.reader.data.News;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;

public class Database {

	private DatabaseHelper db;
	private SQLiteDatabase dbLink;

	public boolean open(Context context) {
		try {
			db = new DatabaseHelper(context);
			dbLink = db.getWritableDatabase();
		} catch (SQLiteException e) {
			return false;
		}

		return true;
	}

	private Cursor getManifest(int itemID) {
		final Cursor results = dbLink.query(DatabaseHelper.TABLE_CATEGORIES,
				null, "itemID=?", new String[] { "" + itemID }, null, null,
				null);

		if (!results.moveToFirst()) {
			return null;
		}

		return results;
	}

	private long updateManifest(Cursor cursor, int position, int itemID,
			boolean exists) {
		ContentValues values = new ContentValues();
		final String[] categories = DatabaseHelper.CATEGORIES;

		final int length = DatabaseHelper.CATEGORIES.length;
		for (int i = 0, j = 0; i < length; i++, j++) {
			if (i == position) {
				values.put(categories[i], exists ? 1 : 0);
				continue;
			}

			values.put(categories[i], cursor.getInt(j));
		}

		return dbLink.update(DatabaseHelper.TABLE_CATEGORIES, values,
				"itemID=?", new String[] { "" + itemID });
	}

	private long insertManifest(int position) {
		ContentValues values = new ContentValues();
		final String[] categories = DatabaseHelper.CATEGORIES;

		final int length = DatabaseHelper.CATEGORIES.length;
		for (int i = 0; i < length; i++) {
			if (i == position) {
				values.put(categories[i], 1);
				continue;
			}

			values.put(categories[i], 0);
		}

		return dbLink.insert(DatabaseHelper.TABLE_CATEGORIES, null, values);
	}
	
	public long deleteManifest(int itemID) {
		return dbLink.delete(DatabaseHelper.TABLE_CATEGORIES, "itemID=?", new String[] { "" + itemID });
	}

	public long putArticle(int position, News news) {
		final Cursor cursor = getManifest(news.getItemID());

		// Does not exist in manifest
		if (cursor == null) {
			insertManifest(position);
			return insertArticle(news);
		} else {
			return updateManifest(cursor, position, news.getItemID(), true);
		}
	}

	private long insertArticle(News news) {
		ContentValues values = new ContentValues();
		values.put("itemID", news.getItemID());
		values.put("title", news.getTitle());
		values.put("URL", news.getURL());
		values.put("points", news.getPoints());
		values.put("postedAgo", news.getPostedAgo());
		values.put("postedBy", news.getPostedBy());
		values.put("comments", news.getComments());

		return dbLink.insert(DatabaseHelper.TABLE_DATA, null, values);
	}
	
	private long deleteArticle(int itemID) {
		return dbLink.delete(DatabaseHelper.TABLE_DATA, "itemID=?", new String[] { "" + itemID });
	}
	
	public void removeArticle(int position, int itemID) {
		final Cursor cursor = getManifest(itemID);
		updateManifest(cursor, position, itemID, false);
		
		final int length = cursor.getColumnCount();
		boolean deleteManifest = true;
		for(int i = 2; i < length; i++) {
			if(i == position) {
				continue;
			}
			
			if(cursor.getInt(i) == 1) {
				deleteManifest = false;
			}
		}
		
		if(!deleteManifest) {
			deleteManifest(itemID);
			deleteArticle(itemID);
		}
	}

	public Cursor getArticle(int itemID) {
		return dbLink.query(DatabaseHelper.TABLE_DATA, null, "itemID=?",
				new String[] { "" + itemID }, null, null, null);
	}
}
