/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader.database;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class DatabaseHelper extends SQLiteOpenHelper {

	private static final String DATABASE_NAME = "main.db";
	private static final int DATABASE_VERSION = 1;

	protected static final String[] CATEGORIES = { "homepage", "newest", "best", "ask" };
	
	public static String getHomepage() {
		return CATEGORIES[0];
	}
	
	public static String getNewest() {
		return CATEGORIES[1];
	}
	
	public static String getBest() {
		return CATEGORIES[2];
	}
	
	public static String getAsk() {
		return CATEGORIES[3];
	}
	
	public static final String TABLE_HOMEPAGE = "homepage";
	public static final String TABLE_NEWEST = "newest";
	public static final String TABLE_BEST = "best";
	public static final String TABLE_ASK_HN = "ask";

	public static final String TABLE_CATEGORIES = "categories";
	public static final String TABLE_DATA = "data";

	public DatabaseHelper(Context context) {
		super(context, DATABASE_NAME, null, DATABASE_VERSION);
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		/*
		 * db.execSQL(createTable(TABLE_HOMEPAGE));
		 * db.execSQL(createTable(TABLE_NEWEST));
		 * db.execSQL(createTable(TABLE_BEST));
		 * db.execSQL(createTable(TABLE_ASK_HN));
		 */

		db.execSQL("CREATE TABLE " + TABLE_CATEGORIES
				+ " (_id INTEGER PRIMARY KEY AUTOINCREMENT, itemID INTEGER, "
				+ TABLE_HOMEPAGE + " INTEGER, " + TABLE_NEWEST + " INTEGER, "
				+ TABLE_BEST + " INTEGER, " + TABLE_ASK_HN + " INTEGER);");

		db.execSQL("CREATE TABLE "
				+ TABLE_DATA
				+ " (_id INTEGER PRIMARY KEY AUTOINCREMENT, itemID INTEGER, title TEXT, URL TEXT, points TEXT, postedAgo TEXT, postedBy TEXT, comments TEXT);");
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_HOMEPAGE + ";");
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_NEWEST + ";");
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_BEST + ";");
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_ASK_HN + ";");
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_DATA + ";");

		onCreate(db);
	}

	/*private String createTable(String table) {
		return "CREATE TABLE " + table + " (_id INTEGER PRIMARY KEY);";
	}*/

}
