/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader.functions;

import java.util.ArrayList;

import yet.another.hackernews.reader.R;
import yet.another.hackernews.reader.data.News;
import android.content.Context;
import android.text.Html;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

public class NewsAdapter extends ArrayAdapter<News> {

	private ArrayList<News> objects;
	private final int textViewId;
	private final LayoutInflater mInflater;

	public NewsAdapter(Context context, int textViewResourceId,
			ArrayList<News> objects) {
		super(context, textViewResourceId, objects);

		this.mInflater = (LayoutInflater) context
				.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		this.objects = objects;
		this.textViewId = textViewResourceId;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		ViewHolder holder;
		
		if (convertView == null) {
			convertView = mInflater.inflate(textViewId, null);
			
			holder = new ViewHolder();
			holder.title = (TextView) convertView.findViewById(R.id.news_title);
			holder.posted = (TextView) convertView.findViewById(R.id.news_posted);
			holder.points = (TextView) convertView.findViewById(R.id.news_points);
			holder.comments = (TextView) convertView.findViewById(R.id.news_comments);
			
			convertView.setTag(holder);
		} else {
			holder = (ViewHolder) convertView.getTag();
		}
		
		final News newsArticle = objects.get(position);	

		if (newsArticle.getTitle() != null) {
			holder.title.setText(Html.fromHtml(newsArticle.getTitle()));
		} else {
			holder.title.setVisibility(View.GONE);
		}

		if (newsArticle.getPostedAgo() != null
				&& newsArticle.getPostedBy() != null) {
			holder.posted.setText(getContext().getString(R.string.news_posted) + " "
					+ newsArticle.getPostedAgo() + " "
					+ getContext().getString(R.string.news_by) + " "
					+ newsArticle.getPostedBy());
		} else {
			holder.posted.setVisibility(View.GONE);
		}

		if (newsArticle.getPoints() != null) {
			holder.points.setText(newsArticle.getPoints());
		} else {
			holder.points.setVisibility(View.GONE);
		}

		if (newsArticle.getPoints() != null) {
			holder.comments.setText(newsArticle.getComments());
		} else {
			holder.comments.setVisibility(View.GONE);
		}

		return convertView;
	}

	static class ViewHolder {
		TextView title;
		TextView posted;
		TextView points;
		TextView comments;
	}

}
