/*******************************************************************************
 * Copyright 2012 Niklas Ekman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 *******************************************************************************/
package yet.another.hackernews.reader.functions;

import yet.another.hackernews.reader.R;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;

import com.actionbarsherlock.app.SherlockDialogFragment;

public class ProgressFragment extends SherlockDialogFragment implements
		OnClickListener {

	public interface OnProgressListener {
		public void OnProgressCancel();
	}

	private static OnProgressListener listener;

	public static ProgressFragment newInstance(String messageID, String titleID) {
		final ProgressFragment f = new ProgressFragment();

		// Attach arguments
		final Bundle args = new Bundle();
		args.putString("message", messageID);
		args.putString("title", titleID);
		f.setArguments(args);

		return f;
	}

	public static void setOnProgressListener(OnProgressListener listener) {
		ProgressFragment.listener = listener;
	}

	@Override
	public Dialog onCreateDialog(Bundle savedInstanceState) {
		final ProgressDialog progressDisplay = new ProgressDialog(
				getSherlockActivity());

		final String title = getArguments().getString("title");
		if (title != null) {
			progressDisplay.setTitle(title);
		}

		// Get message from XML resources
		progressDisplay.setMessage(getArguments().getString("message"));

		if (listener != null) {
			progressDisplay.setButton(ProgressDialog.BUTTON_NEGATIVE,
					getString(R.string.cancel), this);
		}

		progressDisplay.setCancelable(listener == null ? false : true);
		return progressDisplay;
	}

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setRetainInstance(true);
		setCancelable(listener == null ? false : true);
	}

	@Override
	public void onCancel(DialogInterface dialog) {
		super.onCancel(dialog);

		dialog.dismiss();

		if (listener != null) {
			listener.OnProgressCancel();
			listener = null;
		}
	}

	@Override
	public void onClick(DialogInterface dialog, int which) {
		dialog.cancel();
	}
}
